import React, { useState, useEffect } from 'react'
import { Card, List, Icon } from 'semantic-ui-react'
import { Link } from 'react-router'
import { BulletList } from 'react-content-loader'
import { useSelector } from 'react-redux'
import UserChip from './UserChip'
import api from '../../api'
import utils from '../../utils/utils.js'
import FollowButton from './FollowButton'

const FOLLOWING_ENABLED = import.meta.env.VITE_FOLLOWING_ENABLED === 'true'
const GROUP_DISCOVERY_ENABLED = import.meta.env.VITE_GROUP_DISCOVERY_ENABLED === 'true'
const USER_DISCOVERY_ENABLED = import.meta.env.VITE_USER_DISCOVERY_ENABLED === 'true'

export default function ExploreCard ({ count, asCard }) {
  const [highlightProjects, setHighlightProjects] = useState([])
  const [highlightUsers, setHighlightUsers] = useState([])
  const [highlightGroups, setHighlightGroups] = useState([])
  const [loading, setLoading] = useState(false)

  const { user } = useSelector(state => {
    const user = state.users.users.filter(u => state.auth.currentUserId === u._id)[0]
    return { user }
  })
  const userId = user?._id

  useEffect(() => {
    setLoading(true)
    api.search.discover(count || 3, ({ highlightProjects, highlightUsers, highlightGroups }) => {
      setHighlightProjects(highlightProjects)
      if (USER_DISCOVERY_ENABLED) { setHighlightUsers(highlightUsers) }
      if (GROUP_DISCOVERY_ENABLED) { setHighlightGroups(highlightGroups) }
      setLoading(false)
    })
  }, [userId])

  function updateFollowing (updateUserId, following) {
    const newHighlightUsers = Object.assign([], highlightUsers).map(u => {
      if (u._id === updateUserId) return { ...u, following }
      else return u
    })
    setHighlightUsers(newHighlightUsers)
  }

  function getContent () {
    return (
      <div>
        <h4>Discover a project</h4>
        {loading && <BulletList />}
        {highlightProjects?.length > 0 &&
          <>
            <List relaxed>
              {highlightProjects?.map(p =>
                <List.Item key={p._id}>
                  <List.Icon name='book' size='large' verticalAlign='middle' />
                  <List.Content>
                    <List.Header className='umami--click--discover-project' as={Link} to={`/${p.fullName}`}>{p.name}</List.Header>
                  </List.Content>
                </List.Item>
              )}
            </List>
          </>}

        {USER_DISCOVERY_ENABLED &&
          <>
            <h4>Find others on {utils.appName()}</h4>
            {loading && <BulletList />}
            {highlightUsers?.length > 0 &&
              <>
                <List relaxed>
                  {highlightUsers?.map(u =>
                    <List.Item key={u._id}>
                      <List.Content>
                        <div style={{ display: 'flex', alignItems: 'center', justifyContent: 'space-between' }}>
                          <UserChip user={u} className='umami--click--discover-user' />
                          <div>
                            {FOLLOWING_ENABLED &&
                              <FollowButton compact targetUser={u} onChange={f => updateFollowing(u._id, f)} />}
                          </div>
                        </div>
                      </List.Content>
                    </List.Item>
                  )}
                </List>
              </>}
          </>}

        {GROUP_DISCOVERY_ENABLED &&
          <>
            <h4>Discover a group</h4>
            {loading && <BulletList />}
            {highlightGroups?.length > 0 &&
              <>
                {highlightGroups?.map(g =>
                  <div key={g._id} style={{ display: 'flex', alignItems: 'center', marginBottom: 10 }}>
                    {g.imageUrl
                      ? <div style={{ display: 'inline-block', width: '30px', height: '30px', overflow: 'hidden', borderRadius: 7, backgroundImage: `url(${g.imageUrl})`, backgroundSize: 'cover', backgroundPosition: 'center' }} />
                      : <div style={{ width: '30px', textAlign: 'center' }}><Icon name='users' size='large' verticalAlign='middle' /></div>}
                    <Link to={`/groups/${g._id}`} style={{ marginLeft: 10 }}>{g.name}</Link>
                  </div>
                )}
              </>}
          </>}
      </div>
    )
  }

  if (asCard) {
    return (
      <Card fluid>
        <Card.Content>
          {getContent()}
        </Card.Content>
      </Card>
    )
  }

  return getContent()
}
