import React, { useState } from 'react'
import { Helmet } from 'react-helmet'
import { Container, Message, Divider, Button, Form, FormField } from 'semantic-ui-react'
import { toast } from 'react-toastify'
import { useSearchParams } from 'react-router'
import api from '../../api'

const APP_NAME = import.meta.env.VITE_APP_NAME
const ONLINE_SAFETY_URL = import.meta.env.VITE_ONLINE_SAFETY_URL
const ONLINE_SAFETY_POLICY_URL = import.meta.env.VITE_ONLINE_SAFETY_POLICY_URL
const PRIVACY_POLICY_URL = import.meta.env.VITE_PRIVACY_POLICY_URL

export default function Report () {
  const [searchParams] = useSearchParams()
  const referrerString = searchParams?.get('referrer') || ''
  const [loading, setLoading] = useState(false)
  const [success, setSuccess] = useState(false)
  const [referrer] = useState(referrerString)
  const [url, setUrl] = useState(referrerString)
  const [description, setDescription] = useState('')
  const [email, setEmail] = useState('')

  const submit = () => {
    setLoading(true)
    api.users.submitReport({ referrer, url, description, email: email || null }, () => {
      setLoading(false)
      setSuccess(true)
    }, (err) => {
      setLoading(false)
      toast.error(err.message)
    })
  }

  return (
    <Container style={{ marginTop: '40px' }}>
      <Helmet title='Report Content' />
      <h2>Make a report or complaint</h2>
      <p>Online safety is hugely important for communities like {APP_NAME}. If you see something (e.g. user-generated content) that you consider to be potentially harmful or abusive to you or to others, please report it to us using the form below.</p>
      <p>You can also use the form to submit a complaint about content, our duty of care, our handling of previous complaints or content moderations, or anything else relevant to online safety or the operation of {APP_NAME}.</p>
      <p>We review all reports and will take appropriate action as soon as possible.</p>

      {ONLINE_SAFETY_URL &&
        <Message>Read more about <a href={import.meta.env.VITE_ONLINE_SAFETY_URL} target='_blank' rel='noopener noreferrer'>Online Safety on {import.meta.env.VITE_APP_NAME}</a>.</Message>}

      <Divider />

      {success
        ? (
          <div>
            <h3>Thank you for your report</h3>
            <p>Your report has been submitted. We will review it as soon as possible.</p>
          </div>)
        : (
          <Form>
            <FormField>
              <label>URL or description of the content you saw</label>
              <p><small>If the information here is too vague, we may not be able to find what you are referring to. If we have auto-filled it for you, you can leave it as it is.</small></p>
              <input placeholder='https://www...' value={url} onChange={e => setUrl(e.target.value)} />
            </FormField>
            <FormField>
              <label>Please describe the nature of your report or complaint</label>
              <p><small>For example: What is the issue? Why do you think the content is harmful or abusive? What is your complaint?</small></p>
              <textarea placeholder='Please provide as much detail as possible.' value={description} onChange={e => setDescription(e.target.value)} />
            </FormField>
            <FormField>
              <label>Your email address</label>
              <p><small>This is optional. If you choose not to provide it you acknowledge that we will not be able to contact you regarding this submission.</small></p>
              <input placeholder='jane@example.com' type='email' value={email} onChange={e => setEmail(e.target.value)} />
            </FormField>

            <Message>
              {PRIVACY_POLICY_URL &&
                <span>Your information will be processed according to our <a href={PRIVACY_POLICY_URL} target='_blank' rel='noreferrer'>Privacy Policy</a>.</span>}
              {ONLINE_SAFETY_POLICY_URL &&
                <span> Your complaint or report will be handled according to our <a href={ONLINE_SAFETY_POLICY_URL} target='_blank' rel='noreferrer'>Online Safety Policy</a>.</span>}
            </Message>
            <Button loading={loading} color='teal' onClick={submit}>Submit report</Button>
          </Form>)}
    </Container>
  )
}
